@@ -30,7 +30,7 @@ import java.util.Set;
 import java.util.function.Consumer;
 import java.util.function.Supplier;
 
-import javax.enterprise.inject.spi.InterceptionType;
+import jakarta.enterprise.inject.spi.InterceptionType;
 
 import org.jboss.as.ee.component.BasicComponentInstance;
 import org.jboss.as.ee.component.ComponentConfiguration;
@@ -262,7 +262,7 @@ public class WeldComponentIntegrationProcessor implements DeploymentUnitProcesso
     }
 
     private static void addJsr299BindingsCreateInterceptor(final ComponentConfiguration configuration, final ComponentDescription description, final String beanName, final ServiceName weldServiceName, ServiceBuilder<?> builder, final ServiceName bindingServiceName, final ComponentInterceptorSupport componentInterceptorSupport) {
-        //add the create interceptor that creates the CDI interceptors
+        //add the create interceptor that creates the Jakarta Contexts and Dependency Injection Interceptors
         final Supplier<WeldBootstrapService> weldContainerSupplier = builder.requires(weldServiceName);
         final Supplier<InterceptorBindings> interceptorBindingsSupplier = builder.requires(bindingServiceName);
         final Jsr299BindingsCreateInterceptor createInterceptor = new Jsr299BindingsCreateInterceptor(weldContainerSupplier, interceptorBindingsSupplier, description.getBeanDeploymentArchiveId(), beanName, componentInterceptorSupport);
@@ -283,10 +283,6 @@ public class WeldComponentIntegrationProcessor implements DeploymentUnitProcesso
         configuration.addAroundConstructInterceptor(new ImmediateInterceptorFactory(WeldConstructionStartInterceptor.INSTANCE), InterceptorOrder.AroundConstruct.CONSTRUCTION_START_INTERCEPTOR);
     }
 
-    @Override
-    public void undeploy(DeploymentUnit context) {
-    }
-
     /**
      * Retrieves ManagedReference from the interceptor context and performs an InjectionTarget operation on the instance
      */
